==> test-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/test/DummyJeeServer.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.test;

import java.io.Serializable;
import java.util.Map;

import com.xebialabs.deployit.ChangePlan;
import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;
import com.xebialabs.deployit.Discoverable;

@SuppressWarnings("serial")
@ConfigurationItem
public class DummyJeeServer extends TestConfigurationItem implements Serializable, Discoverable<DummyJeeServer>{

	@ConfigurationItemProperty
	private String name;

	public String getName() {
    	return name;
    }

	public void setName(String name) {
    	this.name = name;
    }
	
	public DummyJeeServer discover(Map<String, Object> info, ChangePlan cp) {
		// properties will be updated from the step in real scenario, but for
		// testing purpose 'name' field is upldated here manually
		this.name = "actualName";
		return this;
	}

	public DummyJeeServer discoverChildrenInfo(Map<String, Object> info,
			ChangePlan cp) {
		return this;
	}

	
}

==> test-plugin-3.0.3-sources.jar: com/xebialabs/deployit/plugin/test/DummyJeeServer.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.test;

import static com.xebialabs.deployit.ConfigurationItemRoot.INFRASTRUCTURE;

import java.io.Serializable;
import java.util.Map;

import com.xebialabs.deployit.ChangePlan;
import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;
import com.xebialabs.deployit.Discoverable;

@SuppressWarnings("serial")
@ConfigurationItem(root=INFRASTRUCTURE)
public class DummyJeeServer extends TestConfigurationItem implements Serializable, Discoverable<DummyJeeServer>{

	@ConfigurationItemProperty
	private String name;

	public String getName() {
    	return name;
    }

	public void setName(String name) {
    	this.name = name;
    }
	
	public DummyJeeServer discover(Map<String, Object> info, ChangePlan cp) {
		// properties will be updated from the step in real scenario, but for
		// testing purpose 'name' field is upldated here manually
		this.name = "actualName";
		return this;
	}

	public DummyJeeServer discoverChildrenInfo(Map<String, Object> info,
			ChangePlan cp) {
		return this;
	}

	
}
